@@ -3,16 +3,16 @@
 #' Calculate the time spent on the experiment.
 #' If not stated otherwise, the calculation only starts at the end of
 #' the first page!
-#' @param oTree A list of data frames that were created 
+#' @param oTree A list of data frames that were created
 #' by \code{\link{import_otree}}.
-#' @param pcode Character. The value of the \code{participant.code} 
+#' @param pcode Character. The value of the \code{participant.code}
 #' variable if the time should only be calculated for one specified participant.
-#' @param plabel Character. The value of the \code{participant.label} variable 
+#' @param plabel Character. The value of the \code{participant.label} variable
 #' if the time should only be calculated for one specified participant.
 #' @param group_id Integer. The value of the group_id variable if the
 #' time should only be calculated for one specified group. The \code{group_id}
 #' variable can be created with \code{\link{make_ids}}.
-#' @param seconds Logical. \code{TRUE} if the output should be in seconds 
+#' @param seconds Logical. \code{TRUE} if the output should be in seconds
 #' instead of minutes.
 #' @param rounded Logical. \code{TRUE} if the output should be rounded.
 #' @param digits Integer. The number of digits to which the output
@@ -30,9 +30,9 @@
 #' additional information in the data frame
 #' of single durations, \code{"session_code"} to use session codes,
 #' or \code{NULL} if no session column should be shown.
-#' @param combine Logical. \code{TRUE} if all variables referring to epoch time 
+#' @param combine Logical. \code{TRUE} if all variables referring to epoch time
 #' should be merged, and all variables referring to participant code should
-#' be merged in case data of several versions of oTree are used. 
+#' be merged in case data of several versions of oTree are used.
 #' If \code{FALSE},
 #' the function returns an error if several oTree versions' data are present.
 #' @returns
@@ -53,13 +53,13 @@
 #'
 #' - \code{$messages} = All important notes to the calculations.
 #'
-#' - \code{$only_one_page} = A vector of all individuals who 
+#' - \code{$only_one_page} = A vector of all individuals who
 #' only have one time stamp.
 #' @keywords oTree
 #' @details
 #' This functions calculates the time spent on the experiment by using
 #' the variable that refers to the time stamp. If that variable is not
-#' present, the function alternatively uses \code{seconds_on_page2}, 
+#' present, the function alternatively uses \code{seconds_on_page2},
 #' which can be created with the \code{\link{pagesec}} function.
 #' @examples
 #' # Use package-internal list of oTree data frames
@@ -74,7 +74,6 @@
 #' # Make a data frame of durations (beginning from the end of the second page)
 #' extime(oTree, startat = 2)
 
-
 #' @export
 extime <- function(
     oTree,
@@ -88,16 +87,16 @@ extime <- function(
     tz = "UTC",
     sinfo = "session_code",
     combine = TRUE) {
-  
+
   # Info: epoch_time is called epoch_time_completed in the new oTree version.
   # The code works nevertheless.
   # Old Version of oTree (time_stamp & participant__code)
   # New Version of oTree (epoch_time & participant_code)
-  
+
   firststageproblemparticipants <- character(0L)
   messages <- character(0L)
   othertime <- FALSE
-  
+
   # Define error and warning messages  ####
   errormax1min1 <- paste0(
     "Warning: For at least one participant, the experiment only has one page. ",
@@ -105,42 +104,41 @@ extime <- function(
     "See $only_one_page for information on this participant",
     "/these participants! Participants in this list are not included in the ",
     "output.")
-  
+
   errormax1min1_specific <- paste0(
     "Warning: For this participant, the experiment only has one page. ",
     "I.e., the indices for the first and the last page are the same. ")
-  
+
   indextoohigh <- FALSE
   indextoohigh_message <-
     paste0("The chosen starting value startat is higher than the ",
            "total number of all indices (for at least one case if more participants ",
            "are chosen). Please select a valid starting value.")
-  
+
   indextoolow <- FALSE
   indextoolow_message <-
     paste0("The chosen starting value startat is lower than ",
            "the lowest number of all indices (for at least one case if ",
            "more participants are chosen). Please select a valid starting value.")
-  
-  
+
   # Error handling  ####
   if (is.null(oTree$Time)) {
     stop("There is no \"Time\" data frame.")
   }
-  
+
   if (nrow(oTree$Time) == 0L) {
     stop("Your \"Time\" data frame is empty")
   }
-  
+
   if (startat == "real" && is.null(oTree$all_apps_wide)) {
     stop("The argument \"startat = real\" only works if there is a ",
          "\"all apps wide\" data frame in your oTree list of data frames!")
   }
-  
+
   if (startat != "real" && startat < 1L) {
     stop("Please choose a valid \"startat\"!")
   }
-  
+
   # Check if there are too many epoch times and participant code variables
   withCallingHandlers({
     oTree <- messy_time(oTree, combine = combine)
@@ -154,7 +152,7 @@ extime <- function(
     # list of data frames!
     invokeRestart("muffleWarning")
   })
-  
+
   # Set time variable
   if ("epoch_time" %in% colnames(oTree$Time)) {
     timestamp_var_name <- "epoch_time"
@@ -184,7 +182,7 @@ extime <- function(
       "\"epoch_time_completed,\" ",
       "\"time stamp,\" or \"seconds_on_page2\".")
   }
-  
+
   # Set participant code variable
   if ("participant_code" %in% colnames(oTree$Time)) {
     participant_code_name <- "participant_code"
@@ -196,46 +194,46 @@ extime <- function(
          "This should be a variable called either \"participant_code,\" or",
          "\"participant__code.\"")
   }
-  
+
   # Other errors  ####
   if (length(pcode) > 1L) {
     stop("Please enter only one participant!")
   }
-  
+
   if (!is.null(sinfo) &&
       !(sinfo %in% c("session_code", "session_id"))) {
     stop("Please specify a valid sinfo! Possibilities are ",
          "\"session_code\" or \"session_id\"")
   }
-  
+
   if (!is.null(pcode) && !is.null(group_id)) {
     stop("Please specify either the pcode or the group_id, ",
          "but not both together.")
   }
-  
+
   if (!is.null(pcode) &&
       !(pcode %in% oTree$Time[[participant_code_name]])) {
     stop("The participant is not in the \"Time\" data frame.")
-    
+
   }
-  
+
   if (!is.null(plabel) && !is.null(group_id)) {
     stop("Please enter only plabel or group_id")
   }
-  
+
   if (!is.null(pcode) && !is.null(plabel)) {
     stop("Please enter only pcode or plabel")
   }
-  
+
   if (length(plabel) > 1L) {
     stop("Please enter only one participant label!")
   }
-  
+
   if (is.null(oTree$all_apps_wide) && !is.null(plabel)) {
     stop("You can only use the argument plabel ",
          "if there is an all_apps_wide-data frame in your oTree list")
   }
-  
+
   if (!is.null(group_id) &&
       !is.null(oTree$Time) &&
       is.null(oTree$Time$group_id)) {
@@ -244,7 +242,7 @@ extime <- function(
          "Please run make_ids first before using this function. ",
          "(Use argument gmake = TRUE.)")
   }
-  
+
   if (!is.null(group_id) &&
       !is.null(oTree$Time$group_id) &&
       !(group_id %in% oTree$Time$group_id)) {
@@ -252,13 +250,13 @@ extime <- function(
          group_id,
          "is not in your \"Time\" data frame.")
   }
-  
+
   if (!is.null(sinfo) &&
       sinfo == "session_id" &&
       is.null(oTree$Time$session_id)) {
     stop("There is no session_id in the \"Time\" data frame")
   }
-  
+
   if (!is.null(sinfo) &&
       sinfo == "session_code" &&
       is.null(oTree$Time$session_code) &&
@@ -271,16 +269,16 @@ extime <- function(
       "argument sinfo = NULL if you do not need session information."
     )
   }
-  
+
   # Check for several session_code infos in Time data frame
   if (!is.null(sinfo)) {
-    
+
     # Check if there are old and new session_code variables
     length_session_code_variables <- sum(
       c("session_code",
         "session__code",
         "participant__session__code") %in% colnames(oTree$Time))
-    
+
     if (length_session_code_variables > 1L) {
       # Are there old oTree versions where this could be relevant?
       # I did not test for multiple session codes in messy_time()
@@ -292,19 +290,19 @@ extime <- function(
            "into a single one.")
     }
   }
-  
+
   # Seconds  ####
   if (seconds) {
     divsec <- 1
   } else {
     divsec <- 60 # Divide seconds by 60 to get minutes
   }
-  
+
   # Transform plabel to pcode identifier  ####
   if (!is.null(plabel)) {
     if (length(unique(oTree$all_apps_wide$participant.label)) ==
         length(oTree$all_apps_wide$participant.label)) {
-      
+
       pcode <- oTree$all_apps_wide$participant.code[
         oTree$all_apps_wide$participant.label == plabel]
     } else {
@@ -313,7 +311,7 @@ extime <- function(
            "not working in such a case!")
     }
   }
-  
+
   # Make sub functions 1 - indices and time stamps and durations  ####
   calc_max_index <- function(allindices) {
     max_index <- if (length(allindices)) {
@@ -323,115 +321,114 @@ extime <- function(
     }
     return(max_index)  # Returns to higher level function
   }
-  
+
   min_max_stamps_dur_spec <- function(allindices,
                                       who,
                                       max_index = max_index) {
-    
+
     # First time stamp for specific individuals
     if (startat == "real") {
       # This does not work with seconds_per_page.
       # This was already controlled above!
-      
+
       mintimestamp <- as.numeric(
         as.POSIXct(oTree$all_apps_wide$participant.time_started[
           oTree$all_apps_wide$participant.code == who
         ], tz = tz))
-      
+
     } else {
       # Check if startat is valid
       if (startat > length(allindices)) {
         indextoohigh <<- TRUE
         stop(indextoohigh_message)
-        
+
       } else if (startat < min(allindices)) {
         indextoolow <<- TRUE
         stop(indextoolow_message)
       }
-      
+
       # Assign minimum time stamp
       mintimestamp <- oTree$Time[[timestamp_var_name]][
         !is.na(oTree$Time[[participant_code_name]]) &
           oTree$Time[[participant_code_name]] == who &
           oTree$Time$page_index == allindices[[startat]]]
     }
-    
+
     # Last time stamp for specific individuals
     maxtimestamp <- oTree$Time[[timestamp_var_name]][
       !is.na(oTree$Time[[participant_code_name]]) &
         oTree$Time[[participant_code_name]] == who &
         oTree$Time$page_index == max_index]
-    
+
     # Duration of the whole experiment
     duration <- (maxtimestamp - mintimestamp) / divsec
-    
+
     return(duration)
   }
-  
-  
+
   # Make sub functions 2 - duration calculation  ####
   duration_specific <- function(part_code,
                                 several_participants = FALSE) {
     # Duration for one person
     # Info: Existence of this person in the Time data frame was already checked
     # at the beginning of the extime function!
-    
+
     # For list/Duration for several individuals
     # Info: List of participants is from the Time data frame itself
     # Hence, no need to control for empty index vectors
-    
+
     # Get indices - specific
     allindices <-
       oTree$Time$page_index[
         oTree$Time[[participant_code_name]] == part_code]
     allindices <- allindices[!is.na(allindices)]
     max_index <- calc_max_index(allindices)
-    
+
     # Calculate time - specific
     if ((max_index == 1L && min(allindices) == 1L) ||
         max_index == 0L)  {
-      
+
       # Warning: If there is only one page in the experiment
-      firststageproblemparticipants <<- 
+      firststageproblemparticipants <<-
         c(firststageproblemparticipants, part_code)
-      
+
       if (!several_participants) {
         messages <<- c(messages, errormax1min1_specific)
       } else if (several_participants) {
         messages <<- c(messages, errormax1min1)
       }
       duration <- NA
-      
+
     } else {
-      
+
       if (!othertime) {
         # Get time stamps and duration
         duration <- min_max_stamps_dur_spec(allindices = allindices,
                                             who = part_code,
                                             max_index = max_index)
-        
+
       } else {
         # Get duration
-        
+
         if ("seconds_on_page" %in% names(oTree$Time)) {
           secondsonetwo <- "seconds_on_page"
         } else {
           secondsonetwo <- "seconds_on_page2"
         }
-        
+
         duration <- sum(oTree$Time[[secondsonetwo]][
           !is.na(oTree$Time[[participant_code_name]]) &
             oTree$Time[[participant_code_name]] == part_code &
             oTree$Time$page_index > allindices[[startat]]], na.rm = TRUE)
-        
+
         duration <- duration / divsec
       }
     }
-    
+
     # Return output - specific to next higher level
     return(duration)
   }
-  
+
   # Get session information for singledurations table
   get_session <- function(who) {
     if (is.null(sinfo)) {
@@ -441,13 +438,13 @@ extime <- function(
         session <- unique(oTree$Time$session_id[
           !is.na(oTree$Time[[participant_code_name]]) &
             oTree$Time[[participant_code_name]] == who])
-        
+
       } else if (sinfo == "session_code") {
         if (!is.null(oTree$Time$session_code)) {
           session <- unique(oTree$Time$session_code[
             !is.na(oTree$Time[[participant_code_name]]) &
               oTree$Time[[participant_code_name]] == who])
-          
+
         } else if (!is.null(oTree$Time$session__code)) {
           # Is that even happening? I don't have such data yet.
           session <- unique(oTree$Time$session__code[
@@ -458,51 +455,51 @@ extime <- function(
     }
     return(session)
   }
-  
+
   # Make output for several/all individuals
   output_all <- function() {
     output <- list()
-    
+
     output[["mean_duration"]] <- ifelse(
       rounded,
       round(mean(singledurations[, "duration"]),
             digits = digits),
       mean(singledurations[, "duration"])
     )
-    
+
     output[["min_duration"]] <- ifelse(
       rounded,
       round(min(singledurations[, "duration"]),
             digits = digits),
       min(singledurations[, "duration"])
     )
-    
+
     output[["max_duration"]] <- ifelse(
       rounded,
       round(max(singledurations[, "duration"]),
             digits = digits),
       max(singledurations[, "duration"])
     )
-    
+
     output[["single_durations"]] <-
       singledurations[order(singledurations$duration), ]
-    
+
     if (rounded) {
       output[["single_durations"]][["duration"]] <-
         round(output[["single_durations"]][["duration"]], digits = digits)
     }
-    
+
     if (length(unique(messages) > 0L)) {
       output[["messages"]] <- unique(messages)
     }
-    
+
     if (length(firststageproblemparticipants) > 0L) {
       output[["only_one_page"]] <- firststageproblemparticipants
     }
-    
+
     if (length(warningparticipants) > 0L) {
       output[["warnings"]] <- unique(warningparticipants)
-      
+
       output[["messages"]] <-
         c(output[["messages"]],
           paste0("For some participants, no duration could be ",
@@ -510,14 +507,14 @@ extime <- function(
                  "make it to the app(s) or are there data ",
                  "there twice?"))
     }
-    
+
     # Directly to final return
     return(output)
   }
-  
+
   # Calculate time for specified individuals
   time_for_specific <- function() {
-    
+
     # Get time
     withCallingHandlers({
       duration <- duration_specific(part_code = pcode)   # Info: Messages are set here
@@ -527,7 +524,7 @@ extime <- function(
       warning(w)
       invokeRestart("muffleWarning")
     })
-    
+
     # Make output
     if (rounded) {
       duration <- round(duration, digits = digits)
@@ -538,7 +535,7 @@ extime <- function(
     }
     return(duration)
   }
-  
+
   # Choose between time specific or time for more individuals  ####
   if (!is.null(pcode)) {
     withCallingHandlers({
@@ -552,7 +549,7 @@ extime <- function(
   } else {    # Time for all participants  ####
     singledurations <- data.frame()
     warningparticipants <- c()
-    
+
     # Make list of all participants for all groups ####
     if (is.null(group_id)) {
       listallparticipants <- c(unique(oTree$Time[[participant_code_name]]))
@@ -560,18 +557,18 @@ extime <- function(
       listallparticipants <- unique(oTree$Time[[participant_code_name]][
         oTree$Time$group_id == group_id])
     }
-    
+
     # Calculate time for all participants  ####
     for (i in listallparticipants) {
       tryCatch(
         {
           duration <- duration_specific(part_code = i,
                                         several_participants = TRUE)
-          
+
           if (length(duration) > 1L) stop("One participant is there twice")
-          
+
           session <- get_session(who = i)
-          
+
           # Make data frame  ####
           if (!is.na(duration)) {
             singledurations <- plyr::rbind.fill(
@@ -584,22 +581,22 @@ extime <- function(
                 duration = duration
               )
             )
-            
+
             if (is.null(sinfo)) {
               singledurations <- singledurations[, c("participant", "duration")]
             }
           }
         }, error = function(e) {
           warningparticipants <<- c(warningparticipants, i)
-          
+
         }, warning = function(w) {
-          warning(paste("Warning: ", w))
+          warning("Warning: ", w)
         }
       )
       if (indextoohigh) stop(indextoohigh_message)
       if (indextoolow) stop(indextoolow_message)
     }
-    
+
     # Make output  ####
     return(output_all())
   }
