@@ -9,33 +9,33 @@
 #' storing the data using the newer oTree version's variable names
 #' and removing the outdated variables.
 #' @keywords oTree
-#' @param oTree A list of data frames that were created 
+#' @param oTree A list of data frames that were created
 #' by \code{\link{import_otree}}.
-#' @param combine Logical. \code{TRUE} if all variables referring to epoch time 
+#' @param combine Logical. \code{TRUE} if all variables referring to epoch time
 #' should be merged and/or all variables referring to participant code should be merged
 #' in case data of several versions of oTree are used.
 #' @param epoch_time Logical. \code{TRUE} if all variables referring to the time
 #' stamp should be checked and merged. Only works if \code{combine = TRUE}.
 #' @param participant Logical. \code{TRUE} if all variables referring to the
-#' participant code should be checked and merged. 
+#' participant code should be checked and merged.
 #' Only works if \code{combine = TRUE}.
 #' @param info Logical. \code{TRUE} if a brief information on the process should
 #' be printed.
 #' @returns
-#' This function searches for multiple variables related to the time stamp 
+#' This function searches for multiple variables related to the time stamp
 #' or the participant code in the \code{$Time} data frame,
 #' which can occur when data from both old and new oTree versions are used.
-#' 
-#' If \code{combine = FALSE}, the function will throw an error 
+#'
+#' If \code{combine = FALSE}, the function will throw an error
 #' if such variables are found.
-#' 
+#'
 #' If \code{combine = TRUE}, the function will not throw an error
 #' if such variables are found.
-#' Instead, it automatically combines the variables into new variables 
-#' and adds them to the original \code{$Time} data frame. 
+#' Instead, it automatically combines the variables into new variables
+#' and adds them to the original \code{$Time} data frame.
 #' This function then returns a duplicate of the original oTree list but
 #' with the \code{$Time} data frame modified.
-#' 
+#'
 #' The new variables are
 #' called \code{epoch_time_completed} and \code{participant_code}.
 #' @examplesIf rlang::is_installed("withr")
@@ -86,7 +86,6 @@ messy_time <- function(oTree,
            "\"time stamp.\" You can do this by using the ",
            "combine-argument of this function.")
 
-
   # Set epoch times first with error messages  ####
   if (epoch_time) {
     time_names <- c("epoch_time", "epoch_time_completed", "time_stamp")
@@ -96,7 +95,7 @@ messy_time <- function(oTree,
     other_time_names <- time_names_in_otree[
       time_names_in_otree != "epoch_time_completed"]
 
-    if (length_epoch_times > 1) {
+    if (length_epoch_times > 1L) {
       if (!combine) {
         stop_messages <- c(stop_messages, time_stopmessage)
 
@@ -125,7 +124,7 @@ messy_time <- function(oTree,
 
         warning_messages <- c(warning_messages, paste0(
                 "More than one variable referred to the time ",
-                "stamp. You asked for combining them with the ",
+                "stamp. You asked to combine them with the ",
                 "argument combine = TRUE. ",
                 "Variable(s) \"",
                 paste(other_time_names, collapse = ",\" and \""),
@@ -144,7 +143,7 @@ messy_time <- function(oTree,
     if (length_part_codes > 1L) {
       if (!combine) {
         stop_messages <- c(stop_messages, participant_stopmessage)
-        
+
       } else if (combine) {
         # Combine participant codes
         oTree$Time$participant_code[is.na(oTree$Time$participant_code)] <-
@@ -152,7 +151,7 @@ messy_time <- function(oTree,
         oTree$Time$participant__code <- NULL
         warning_messages <- c(warning_messages, paste0(
                 "More than one variable referred to the participant code. ",
-                "You asked for combining them with the ",
+                "You asked to combine them with the ",
                 "argument combine = TRUE. ",
                 "Variable \"participant__code\" was integrated into ",
                 "variable \"participant_code\" ",
@@ -162,7 +161,7 @@ messy_time <- function(oTree,
   }
 
   # Return all error messages and warning messages  ####
-  if (length(stop_messages) > 0) {
+  if (length(stop_messages) > 0L) {
     stop(paste(stop_messages, collapse  = "\n"))
   }
 
